@@ -1,6 +1,5 @@
 import sys
 import os.path
-from os import mkdir
 from pathlib import Path
 from datetime import datetime
 
@@ -16,14 +15,20 @@ from PIL import Image, ImageTk
 import webbrowser
 from random import choice
 
-from .files_earch_frame import FileSearchFrame
-from .device_info import DeviceInfoFrame
+if __package__:
+    from .files_earch_frame import FileSearchFrame
+    from .device_info import DeviceInfoFrame
+else:
+    sys.path.append(os.path.dirname(__file__))
+    from files_earch_frame import FileSearchFrame
+    from device_info import DeviceInfoFrame
 
 cap = cv2.VideoCapture(0)
 INTERVAL = 100 # ms
 SAVE_DIR = 'ocam_captures/'
 PADDING = 9
 DEFAULT_WINSIZE = '500x400'
+ENABLE_FULLSCREEN = False
 PATH = Path(__file__).parent
 
 def get_timestamp():   
@@ -241,7 +246,7 @@ class MainApp(ttk.Frame):
 
         fapp= ttk.Toplevel(app)
         fapp.geometry(DEFAULT_WINSIZE)
-        fapp.attributes('-fullscreen', True)
+        fapp.attributes('-fullscreen', ENABLE_FULLSCREEN)
         fapp.title("拍摄文件一览")
         FileSearchFrame(fapp, SAVE_DIR, fix_path=True, init=True)
 
@@ -249,7 +254,7 @@ class MainApp(ttk.Frame):
 
         dapp= ttk.Toplevel(app)
         dapp.geometry(DEFAULT_WINSIZE)
-        dapp.attributes('-fullscreen', True)
+        dapp.attributes('-fullscreen', ENABLE_FULLSCREEN)
         dapp.title("设备信息")
         DeviceInfoFrame(dapp)
 
@@ -286,7 +291,7 @@ if __name__ == '__main__':
 
     app = ttk.Window("oCam", "yeti")
     app.geometry(DEFAULT_WINSIZE)
-    app.attributes('-fullscreen', True)
+    app.attributes('-fullscreen', ENABLE_FULLSCREEN)
     mp = MainApp(app)
 
     # use either q or esc to close window
