@@ -2,7 +2,11 @@
 
 import time
 import math
-from .Adafruit_I2C import Adafruit_I2C
+
+if __package__:
+  from .Adafruit_I2C import Adafruit_I2C
+else:
+  from Adafruit_I2C import Adafruit_I2C
 
 # ============================================================================
 # Adafruit PCA9685 16-Channel PWM Servo Driver
@@ -86,7 +90,7 @@ class PWM :
     self.i2c.write8(self.__LED0_OFF_H+4*channel, off >> 8)
 
   def setAllPWM(self, on, off):
-    #"Sets a all PWM channels"
+    # Sets a all PWM channels
     self.i2c.write8(self.__ALL_LED_ON_L, on & 0xFF)
     self.i2c.write8(self.__ALL_LED_ON_H, on >> 8)
     self.i2c.write8(self.__ALL_LED_OFF_L, off & 0xFF)
