@@ -1,8 +1,15 @@
 import RPi.GPIO as GPIO
 import time
 import sys
-from . import servo, led, joystick, passive_buzzer as pbz
+import os.path
 
+if __package__:
+    from . import servo, led, joystick, passive_buzzer as pbz
+    from .liquidcrystal_i2c import LiquidCrystal_I2C
+else:
+    sys.path.append(os.path.dirname(__file__))
+    import servo, led, joystick, passive_buzzer as pbz
+    from liquidcrystal_i2c import LiquidCrystal_I2C
 '''
 * Currently unused pins
 
@@ -148,7 +155,7 @@ def keyscan():
     while GPIO.input(BtnPin) == False:  # wait for press       
         # val = GPIO.input(BtnPin)
         print('front detection: ', front_detection())
-        print('back detection: ', back_detection())
+        # print('back detection: ', back_detection())
 
     time.sleep(0.1) # after start, set green light on and red off
 
@@ -181,6 +188,10 @@ def setup():
     GPIO.setup(TRIG, GPIO.OUT)
     GPIO.setup(ECHO, GPIO.IN)
 
+    # lcd. now can only control backlight, research later
+    lcd = LiquidCrystal_I2C()
+    lcd.noBacklight()
+
     if ENABLE_BUTTON:
         GPIO.setup(BtnPin, GPIO.IN, pull_up_down=GPIO.PUD_UP)    # Set BtnPin's mode is input, and pull up to high level(3.3V)
     else:
