@@ -7,10 +7,17 @@ from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.constants import *
 from tkinter.scrolledtext import ScrolledText
 from pathlib import Path
-from . import led, acc, servo, joystick
-from . import passive_buzzer as pbz
-from . import PCF8591 as adc
-from . import ds18b20 as temperature
+
+if __package__:
+    from . import led, acc, servo, joystick
+    from . import passive_buzzer as pbz
+    from . import PCF8591 as adc
+    from . import ds18b20 as temperature
+else:
+    import led, acc, servo, joystick
+    import passive_buzzer as pbz
+    import PCF8591 as adc
+    import ds18b20 as temperature
 # import sys
 # sys.path.insert(0, './vehicle')
 # import vehicle.Adafruit_PWM_Servo_Driver as servo_drv
@@ -24,6 +31,7 @@ from ttkbootstrap.toast import ToastNotification
 cap = cv2.VideoCapture(0)
 INTERVAL = 200 # ms
 DEFAULT_WINSIZE = '500x400'
+ENABLE_FULLSCREEN = False
 
 TEST_LED = '1'
 TEST_PASSIVE_BUZZER = '3'
@@ -399,6 +407,26 @@ class MainGui(ttk.Frame):
 - GPIO19 (35) (36) - GPIO16
 - GPIO26 (37) (38) - GPIO20
    GND (39) (40) - GPIO21
+
+I2C devices:
+
+     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
+00:                         -- -- -- -- -- -- -- -- 
+10: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
+20: -- -- -- -- -- -- -- 27 -- -- -- -- -- -- -- -- 
+30: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
+40: 40 -- -- -- -- -- -- -- 48 -- -- -- -- -- -- -- 
+50: -- -- -- -- -- -- -- 57 -- -- -- -- -- -- -- -- 
+60: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
+70: 70 -- -- -- -- -- -- --   
+
+0x27 - LCD1602 PCF8574
+0x40 - servo: PCA9685 16-channel PWM driver
+0x48 - ADC: PCF8591
+0x57 - SpO2 sensor
+0x70 - 
+
+To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
         '''       
 
         self.setvar('scroll-message', _value)
@@ -618,7 +646,7 @@ if __name__ == '__main__':
     
     app = ttk.Window("Raspi Control Panel")
     app.geometry(DEFAULT_WINSIZE)
-    app.attributes('-fullscreen', True)
+    app.attributes('-fullscreen', ENABLE_FULLSCREEN)
 
     MainGui(app)
     app.mainloop()
