@@ -1,5 +1,8 @@
 import RPi.GPIO as GPIO
-from . import Adafruit_PWM_Servo_Driver as servo_drv # Adafruit Industries 是纽约的一家开源硬件公司
+if __package__:
+    from . import Adafruit_PWM_Servo_Driver as servo_drv # Adafruit Industries 是纽约的一家开源硬件公司
+else:
+    import Adafruit_PWM_Servo_Driver as servo_drv
 import time
 
 RUNNING = True
@@ -7,20 +10,6 @@ DELTA = 5 # degrees to to correct servo direction.
 PT_STEP = 5
 IIC_SERVO = 0x40
 
-'''
-pi@raspberrypi:~ $ sudo gpio i2cdetect -y
-     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f
-00:                         -- -- -- -- -- -- -- -- 
-10: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-20: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-30: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-40: 40 -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-50: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-60: -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- 
-70: 70 -- -- -- -- -- -- --    
-'''
-
-
 # Initialise the servo PWM using the default address
 servo_pwm = servo_drv.PWM(IIC_SERVO, debug = False)
 servoMin = 150  # Min pulse length out of 4096
